@@ -26,11 +26,10 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <document/documentjob.h>
 
 // KDE
-#include <KUrl>
+#include <QUrl>
 
 // Qt
 #include <QImage>
-#include <QObject>
 #include <QQueue>
 #include <QUndoStack>
 #include <QWeakPointer>
@@ -43,7 +42,7 @@ struct DocumentPrivate
 {
     Document* q;
     AbstractDocumentImpl* mImpl;
-    KUrl mUrl;
+    QUrl mUrl;
     bool mKeepRawData;
     QWeakPointer<DocumentJob> mCurrentJob;
     DocumentJobQueue mJobQueue;
@@ -78,7 +77,7 @@ public:
     : mInvertedZoom(invertedZoom)
     {}
 
-    void doStart(); // reimp
+    void doStart() Q_DECL_OVERRIDE;
 
     int mInvertedZoom;
 };
